@@ -85,7 +85,7 @@ class Decoupage(object):
             except Exception, e:
                 # record the error, but persist
                 print >> sys.stderr, "Couldn't load formatter: %s" % formatter
-                print >> sts.stderr, e
+                print >> sys.stderr, e
                 continue
             self.formatters[formatter.name] = _formatter
 
@@ -135,7 +135,12 @@ class Decoupage(object):
                 return fileserver(environ, start_response)
         else:
             # file does not exist
-            response = exc.HTTPNotFound()
+            conf = self.conf('/')
+            data = dict(request=request,
+                        title="Not Found")
+            template = self.loader.load('HTTPNotFound.html')
+            body = template.generate(**data).render('html', doctype='html')
+            response = Response(content_type='text/html', body=body, status=404)
             return response(environ, start_response)
 
 
